@@ -1,16 +1,24 @@
 from __future__ import print_function
-from urllib2 import urlopen
-from UserList import UserList
+import sys
+if sys.version_info[0] == 3:
+    PYTHON3 = True
+else:
+    PYTHON3 = False
+
+if PYTHON3:
+    from urllib.request import urlopen
+    from collections import UserList
+    string_representation = str
+else:
+    from urllib2 import urlopen
+    from UserList import UserList
+    string_representation = unicode
+
 from pygments import highlight
 from pygments.lexers import HtmlLexer
 from pygments.formatters import HtmlFormatter
 
-bs4 = None
-try:
-    from bs4 import BeautifulSoup, Tag
-    bs4 = True
-except ImportError:
-    from BeautifulSoup import BeautifulSoup, Tag
+from bs4 import BeautifulSoup, Tag
 
 requests = None
 try:
@@ -18,6 +26,7 @@ try:
 except ImportError:
     pass
 
+
 SHOW_RENDERED_HTML = False
 SHOW_RENDERED_CSS = False
 SHOW_RENDERED_JS = False
@@ -52,7 +61,7 @@ def configure_ipython_beautifulsoup(show_html=False,
 
 
 def cleaned_beautifulsoup_copy(soup):
-    copy = BeautifulSoup(unicode(soup))
+    copy = BeautifulSoup(string_representation(soup))
     if SHOW_RENDERED_JS is not True:
         for node in copy('script'):
             node.extract()
@@ -67,14 +76,14 @@ def cleaned_beautifulsoup_copy(soup):
 def render(self):
     def __render(self):
         if SHOW_RENDERED_HTML:
-            yield unicode(cleaned_beautifulsoup_copy(self))
+            yield string_representation(cleaned_beautifulsoup_copy(self))
             yield u"<hr/>"
 
-        yield unicode(highlight(
+        yield string_representation(highlight(
             self.prettify(),
             HtmlLexer(),
             HtmlFormatter(noclasses=True),
-        ))
+            ))
         yield u"<hr/>"
 
     return u''.join(__render(self))
@@ -92,7 +101,7 @@ class BeautifulSoupList(UserList):
                 yield str(num)
                 yield u"</td>"
                 yield u"<td>"
-                yield unicode(cleaned_beautifulsoup_copy(item))
+                yield string_representation(cleaned_beautifulsoup_copy(item))
                 yield u"</td>"
                 yield u"<td>"
                 yield highlight(
@@ -102,7 +111,7 @@ class BeautifulSoupList(UserList):
                 )
                 yield u"</td>"
                 yield u"</tr>"
-            yield "</table>"
+            yield u"</table>"
         return u''.join(__repr_html(self))
 
     def __getslice__(self, *args, **kwargs):
@@ -125,13 +134,8 @@ def p(url):
 def monkey_patch_beautiful_soup():
     BeautifulSoup._repr_html_ = render
     Tag._repr_html_ = render
-
-    if bs4:
-        BeautifulSoup.find_all = wrap_findall(BeautifulSoup.find_all)
-        Tag.find_all = wrap_findall(Tag.find_all)
-    else:
-        BeautifulSoup.findAll = wrap_findall(BeautifulSoup.findAll)
-        Tag.findAll = wrap_findall(Tag.findAll)
+    BeautifulSoup.find_all = wrap_findall(BeautifulSoup.find_all)
+    Tag.find_all = wrap_findall(Tag.find_all)
 
     return BeautifulSoup, Tag
 
@@ -146,10 +150,10 @@ def load_ipython_extension(ipython):
     print("See `configure_ipython_beautifulsoup?` for configuration"
           " information")
 
-    print("Push 'BeautifulSoup' of '%s' into current context" %
-        ("bs4" if bs4 else "BeautifulSoup"))
+    print("Push 'BeautifulSoup' from 'bs4' into current context")
 
-    print("Push 'urlopen' of 'urllib2' into current context")
+    print("Push 'urlopen' from '%s' into current context" %
+        ("urllib.request" if PYTHON3 else "urllib2"))
     print("Push 'p' shortcut into current context")
 
     try:
